==> haskell-unicode-transforms-0.4.0.1-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-DZhkICoCYaW3kLspNQLNUX
key:                  unicode-transforms-0.4.0.1-DZhkICoCYaW3kLspNQLNUX
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  0158d70adada2b01d37d9f96f5d99817
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-DZhkICoCYaW3kLspNQLNUX
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1 text-2.0.2
    unicode-data-0.5.0-BK7Z3vfyveGHQQHY4NllOY

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.4.0.1-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-transforms
version:              0.4.0.1
visibility:           public
id:                   unicode-transforms-0.4.0.1-KNJzaJY2fnN6X9gPYsZ8Af
key:                  unicode-transforms-0.4.0.1-KNJzaJY2fnN6X9gPYsZ8Af
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  d34d35fca56efa2ea22f0010e2c7cff3
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-transforms-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-transforms
hs-libraries:         HSunicode-transforms-0.4.0.1-KNJzaJY2fnN6X9gPYsZ8Af
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1 text-2.0.2
    unicode-data-0.5.0-E0CaKcQ7Jkz5eSxsiwtcMP

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
